@@ -63,7 +63,7 @@ bonobo_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_info)
 	int dumb_argc = 1;
 	char *dumb_argv[] = {NULL};
 
-	dumb_argv[0] = program_invocation_name;
+	dumb_argv[0] = g_get_prgname ();
 
 	bonobo_init (&dumb_argc, dumb_argv);
 }
@@ -127,7 +127,7 @@ bonobo_activation_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_i
 		int dumb_argc = 1;
 		char *dumb_argv[] = {NULL};
 
-		dumb_argv[0] = program_invocation_name;
+		dumb_argv[0] = g_get_prgname ();
 		(void) bonobo_activation_orb_init (&dumb_argc, dumb_argv);
 		
 		bonobo_activation_postinit (program, mod_info);
@@ -222,7 +222,8 @@ libgnome_option_cb (poptContext ctx, enum poptCallbackReason reason,
 			g_value_init (&value, G_TYPE_STRING);
 			g_value_set_string (&value, opt->arg);
 			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ESPEAKER, &value);
+				      GNOME_PARAM_ESPEAKER, &value,
+				      NULL);
 			g_value_unset (&value);
 			break;
 
@@ -230,7 +231,8 @@ libgnome_option_cb (poptContext ctx, enum poptCallbackReason reason,
 			g_value_init (&value, G_TYPE_BOOLEAN);
 			g_value_set_boolean (&value, FALSE);
 			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ENABLE_SOUND, &value);
+				      GNOME_PARAM_ENABLE_SOUND, &value,
+				      NULL);
 			g_value_unset (&value);
 			break;
 
@@ -238,7 +240,8 @@ libgnome_option_cb (poptContext ctx, enum poptCallbackReason reason,
 			g_value_init (&value, G_TYPE_BOOLEAN);
 			g_value_set_boolean (&value, TRUE);
 			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ENABLE_SOUND, &value);
+				      GNOME_PARAM_ENABLE_SOUND, &value,
+				      NULL);
 			g_value_unset (&value);
 			break;
 
@@ -259,9 +262,9 @@ static void
 libgnome_userdir_setup (gboolean create_dirs)
 {
 	if(!gnome_user_dir) {
-		gnome_user_dir = g_build_filename (g_get_home_dir(), ".gnome", NULL);
+		gnome_user_dir = g_build_filename (g_get_home_dir(), GNOME_DOT_GNOME, NULL);
 		gnome_user_private_dir = g_build_filename (g_get_home_dir(),
-							   ".gnome_private", NULL);
+							   GNOME_DOT_GNOME_PRIVATE, NULL);
 		gnome_user_accels_dir = g_build_filename (gnome_user_dir,
 							  "accels", NULL);
 	}
