@@ -824,7 +824,8 @@ gnome_program_install_property (GnomeProgramClass *pclass,
  * should the returned string.
  *
  * Returns: The full path to the file (if it exists or only_if_exists is
- *          %FALSE) or %NULL.  */
+ *          %FALSE) or %NULL.
+ */
 gchar *
 gnome_program_locate_file (GnomeProgram *program, GnomeFileDomain domain,
 			   const gchar *file_name, gboolean only_if_exists,
@@ -1239,12 +1240,9 @@ gnome_program_preinit (GnomeProgram *program,
     if (program->_priv->state != APP_CREATE_DONE)
 	return NULL;
 
-    /* On non-glibc systems, this is not set up for us.  */
-    if (!program_invocation_name) {
-	program_invocation_name = g_strdup (argv[0]);
-	program_invocation_short_name = g_path_get_basename (program_invocation_name);
-    }
-
+    /* Store invocation name */
+    g_set_prgname (argv[0]);
+    
     /* 0. Misc setup */
     if (program->_priv->app_id)
 	g_free (program->_priv->app_id);
